@@ -8,6 +8,7 @@
  * Copyright 1999, 2000 Ximian, Inc.
  */
 #include <config.h>
+#include <gdk/gdkkeysyms.h>
 #include <gtk/gtksignal.h>
 #include <libgnomeui/gnome-canvas.h>
 #include <libgnomeui/gnome-canvas-util.h>
@@ -294,16 +295,17 @@ finish_editing (ETableClickToAdd *etcta)
 		etcta_add_one (etcta, one);
 		gtk_object_unref(GTK_OBJECT(one));
 
-		e_table_selection_model_clear(etcta->selection);
+		e_selection_model_clear(E_SELECTION_MODEL(etcta->selection));
 
 		etcta->row = gnome_canvas_item_new(GNOME_CANVAS_GROUP(etcta),
 						   e_table_item_get_type(),
 						   "ETableHeader", etcta->eth,
 						   "ETableModel", etcta->one,
 						   "minimum_width", etcta->width,
-						   "drawgrid", TRUE,
-						   "table_selection_model", etcta->selection,
-						   "cursor_mode", E_TABLE_CURSOR_SPREADSHEET,
+						   "horizontal_draw_grid", FALSE,
+						   "vertical_draw_grid", TRUE,
+						   "selection_model", etcta->selection,
+						   "cursor_mode", E_CURSOR_SPREADSHEET,
 						   NULL);
 
 		gtk_signal_connect(GTK_OBJECT(etcta->row), "key_press",
@@ -339,16 +341,17 @@ etcta_event (GnomeCanvasItem *item, GdkEvent *e)
 			etcta_add_one (etcta, one);
 			gtk_object_unref(GTK_OBJECT(one));
 			
-			e_table_selection_model_clear(etcta->selection);
+			e_selection_model_clear(E_SELECTION_MODEL(etcta->selection));
 
 			etcta->row = gnome_canvas_item_new(GNOME_CANVAS_GROUP(item),
 							   e_table_item_get_type(),
 							   "ETableHeader", etcta->eth,
 							   "ETableModel", etcta->one,
 							   "minimum_width", etcta->width,
-							   "drawgrid", TRUE,
-							   "table_selection_model", etcta->selection,
-							   "cursor_mode", E_TABLE_CURSOR_SPREADSHEET,
+							   "horizontal_draw_grid", FALSE,
+							   "vertical_draw_grid", TRUE,
+							   "selection_model", etcta->selection,
+							   "cursor_mode", E_CURSOR_SPREADSHEET,
 							   NULL);
 
 			gtk_signal_connect(GTK_OBJECT(etcta->row), "key_press",
