@@ -14,12 +14,21 @@
  */
 
 #include <config.h>
-#include <stdlib.h>
-#include "gal/util/e-i18n.h"
-#include <libgnomeui/gnome-dialog.h>
-#include <glade/glade.h>
+
 #include "e-table-config.h"
+
+#include <stdlib.h>
+#include <string.h>
+#include <gtk/gtkentry.h>
+#include <gtk/gtklabel.h>
+#include <gtk/gtknotebook.h>
+#include <gtk/gtksignal.h>
+#include <gtk/gtktogglebutton.h>
+#include <libgnomeui/gnome-dialog.h>
+#include <libgnomeui/gnome-propertybox.h>
+#include <glade/glade.h>
 #include "gal/util/e-util.h"
+#include "gal/util/e-i18n.h"
 
 
 #define PARENT_TYPE (gtk_object_get_type())
@@ -49,11 +58,12 @@ config_destroy (GtkObject *object)
 }
 
 static void
-e_table_config_changed       (ETableConfig *config, ETableState *state)
+e_table_config_changed (ETableConfig *config, ETableState *state)
 {
 	g_return_if_fail (config != NULL);
 	g_return_if_fail (E_IS_TABLE_CONFIG (config));
 
+	
 	gtk_signal_emit(GTK_OBJECT(config),
 			e_table_config_signals [CHANGED],
 			state);
@@ -75,8 +85,8 @@ config_class_init (GtkObjectClass *object_class)
 				GTK_RUN_LAST,
 				object_class->type,
 				GTK_SIGNAL_OFFSET (ETableConfigClass, changed),
-				gtk_marshal_NONE__OBJECT,
-				GTK_TYPE_NONE, 1, E_TABLE_STATE_TYPE);
+				gtk_marshal_NONE__NONE,
+				GTK_TYPE_NONE, 0);
 
 	gtk_object_class_add_signals (object_class, e_table_config_signals, LAST_SIGNAL);
 }
@@ -103,7 +113,7 @@ find_model_column_by_name (ETableSpecification *spec, const char *s)
 
 	for (column = spec->columns; *column; column++){
 
-		if (strcasecmp ((*column)->title, s) == 0)
+		if (g_strcasecmp ((*column)->title, s) == 0)
 			return (*column)->model_col;
 	}
 	return -1;
@@ -127,6 +137,7 @@ update_sort_and_group_config_dialog (ETableConfig *config, gboolean is_sort)
 	
 	for (i = 0; i < 4; i++){
 		gboolean sensitive = (i <= count);
+		char *text = "";
 		
 		gtk_widget_set_sensitive (widgets [i].frames, sensitive);
 
@@ -136,6 +147,9 @@ update_sort_and_group_config_dialog (ETableConfig *config, gboolean is_sort)
 		gtk_signal_handler_block (
 			GTK_OBJECT (widgets [i].radio_ascending),
 			widgets [i].toggled_id);
+		gtk_signal_handler_block (
+			GTK_OBJECT (widgets [i].combo->entry),
+			widgets [i].changed_id);
 		
 		if (i < count){
 			GtkToggleButton *a, *d;
@@ -161,18 +175,7 @@ update_sort_and_group_config_dialog (ETableConfig *config, gboolean is_sort)
 				continue;
 			}
 
-			/*
-			 * Change the text
-			 */
-			gtk_signal_handler_block (
-				GTK_OBJECT (widgets [i].combo->entry),
-				widgets [i].changed_id);
-			gtk_combo_text_set_text (
-				widgets [i].combo, gettext (
-					column->title));
-			gtk_signal_handler_unblock (
-				GTK_OBJECT (widgets [i].combo->entry),
-				widgets [i].changed_id);
+			text = gettext (column->title);
 
 			/*
 			 * Update radio buttons
@@ -189,20 +192,25 @@ update_sort_and_group_config_dialog (ETableConfig *config, gboolean is_sort)
 			t = GTK_TOGGLE_BUTTON (
 				widgets [i].radio_ascending);
 
+			if (is_sort)
+				g_assert (widgets [i].radio_ascending != config->group [i].radio_ascending);
+			else
+				g_assert (widgets [i].radio_ascending != config->sort [i].radio_ascending);
 			gtk_toggle_button_set_active (t, 1);
 		}
+
+		/* Set the text */
+		gtk_combo_text_set_text (widgets [i].combo, text);
+
 		gtk_signal_handler_unblock (
 			GTK_OBJECT (widgets [i].radio_ascending),
 			widgets [i].toggled_id);
+		gtk_signal_handler_unblock (
+			GTK_OBJECT (widgets [i].combo->entry),
+			widgets [i].changed_id);
 	}
 }
 
-static void
-update_group_config_dialog (ETableConfig *config)
-{
-	g_warning ("IMPLEMENT ME\n");
-}
-
 static void
 config_sort_info_update (ETableConfig *config)
 {
@@ -250,7 +258,6 @@ config_group_info_update (ETableConfig *config)
 	int count, i;
 
 	count = e_table_sort_info_grouping_get_count (info);
-	printf ("Count of the grouping action: %d\n", count);
 	res = g_string_new ("");
 
 	for (i = 0; i < count; i++) {
@@ -310,7 +317,7 @@ do_sort_and_group_config_dialog (ETableConfig *config, gboolean is_sort)
 	int button, running = 1;
 
 	config->temp_state = e_table_state_duplicate (config->state);
-	
+
 	update_sort_and_group_config_dialog (config, is_sort);
 
 	gtk_widget_grab_focus (GTK_WIDGET (
@@ -342,6 +349,7 @@ do_sort_and_group_config_dialog (ETableConfig *config, gboolean is_sort)
 		case 1:
 			gtk_object_unref (GTK_OBJECT (config->state));
 			config->state = config->temp_state;
+			config->temp_state = 0;
 			running = 0;
 			gnome_property_box_changed (
 				GNOME_PROPERTY_BOX (config->dialog_toplevel));
@@ -364,6 +372,21 @@ do_sort_and_group_config_dialog (ETableConfig *config, gboolean is_sort)
 		config_group_info_update (config);
 }
 
+#if 0
+static GtkWidget *
+e_table_proxy_etable_new (void)
+{
+	return gtk_label_new ("Waiting for the ETable/ETree\nmerger to be commited");
+}
+#endif
+
+static void
+config_button_fields (GtkWidget *widget, ETableConfig *config)
+{
+	gnome_dialog_run (GNOME_DIALOG(config->dialog_show_fields));
+	gnome_dialog_close (GNOME_DIALOG (config->dialog_show_fields));
+}
+		
 static void
 config_button_sort (GtkWidget *widget, ETableConfig *config)
 {
@@ -376,7 +399,6 @@ config_button_group (GtkWidget *widget, ETableConfig *config)
 	do_sort_and_group_config_dialog (config, FALSE);
 }
 
-
 static void
 dialog_destroyed (GtkObject *dialog, ETableConfig *config)
 {
@@ -434,13 +456,13 @@ sort_entry_changed (GtkEntry *entry, ETableConfigSortWidgets *sort)
 	
 	char *s = gtk_entry_get_text (entry);
 
-	if (g_hash_table_lookup (sort->combo->elements, s)){
+	if (s && s [0] && g_hash_table_lookup (sort->combo->elements, s)){
 		ETableSortColumn c;
 		int col;
 		
 		col = find_model_column_by_name (config->source_spec, s);
 		if (col == -1){
-			g_warning ("This should not happen");
+			g_warning ("sort: This should not happen (%s)", s);
 			return;
 		}
 
@@ -535,16 +557,15 @@ group_entry_changed (GtkEntry *entry, ETableConfigSortWidgets *group)
 	ETableSortInfo *sort_info = config->temp_state->sort_info;
 	ETableConfigSortWidgets *base = &config->group[0];
 	int idx = group - base;
-	
 	char *s = gtk_entry_get_text (entry);
 
-	if (g_hash_table_lookup (group->combo->elements, s)){
+	if (s && s [0] && g_hash_table_lookup (group->combo->elements, s)){
 		ETableSortColumn c;
 		int col;
 		
 		col = find_model_column_by_name (config->source_spec, s);
 		if (col == -1){
-			g_warning ("This should not happen");
+			g_warning ("grouping: this should not happen, %s", s);
 			return;
 		}
 
@@ -553,10 +574,10 @@ group_entry_changed (GtkEntry *entry, ETableConfigSortWidgets *group)
 		c.column = col;
 		e_table_sort_info_grouping_set_nth (sort_info, idx, c);
 		  
-		update_group_config_dialog (config);
+		update_sort_and_group_config_dialog (config, FALSE);
 	}  else {
 		e_table_sort_info_grouping_truncate (sort_info, idx);
-		update_group_config_dialog (config);
+		update_sort_and_group_config_dialog (config, FALSE);
 	}
 }
 
@@ -642,8 +663,8 @@ configure_group_dialog (ETableConfig *config, GladeXML *gui)
 static void
 setup_gui (ETableConfig *config)
 {
-	GladeXML *gui = glade_xml_new (
-		ETABLE_GLADEDIR "/e-table-config.glade", NULL);
+	GladeXML *gui = glade_xml_new_with_domain (
+		ETABLE_GLADEDIR "/e-table-config.glade", NULL, PACKAGE);
 	
 	config->dialog_toplevel = glade_xml_get_widget (
 		gui, "e-table-config");
@@ -669,7 +690,8 @@ setup_gui (ETableConfig *config)
 
 	connect_button (config, gui, "button-sort", config_button_sort);
 	connect_button (config, gui, "button-group", config_button_group);
-
+	connect_button (config, gui, "button-fields", config_button_fields);
+	
 	configure_sort_dialog (config, gui);
 	configure_group_dialog (config, gui);
 	
