@@ -35,6 +35,7 @@ enum {
 	ARG_WIDTH,
 	ARG_MINIMUM_WIDTH,
 	ARG_FROZEN,
+	ARG_TABLE_ALTERNATING_ROW_COLORS,
 	ARG_TABLE_HORIZONTAL_DRAW_GRID,
 	ARG_TABLE_VERTICAL_DRAW_GRID,
 	ARG_TABLE_DRAW_FOCUS,
@@ -412,6 +413,7 @@ create_child_node (ETableGroupContainer *etgc, void *val)
 	child = e_table_group_new (GNOME_CANVAS_GROUP (etgc), etg->full_header,
 				   etg->header, etg->model, etgc->sort_info, etgc->n + 1);
 	gnome_canvas_item_set(GNOME_CANVAS_ITEM(child),
+			      "alternating_row_colors", etgc->alternating_row_colors,
 			      "horizontal_draw_grid", etgc->horizontal_draw_grid,
 			      "vertical_draw_grid", etgc->vertical_draw_grid,
 			      "drawfocus", etgc->draw_focus,
@@ -665,6 +667,34 @@ etgc_compute_location (ETableGroup *etg, int *x, int *y, int *row, int *col)
 	}
 }
 
+static void
+etgc_get_cell_geometry (ETableGroup *etg, int *row, int *col, int *x, int *y, int *width, int *height)
+{
+	ETableGroupContainer *etgc = E_TABLE_GROUP_CONTAINER(etg);
+
+	int ypos;
+
+	ypos = 0;
+
+	if (etgc->children) {
+		GList *list;
+		for (list = etgc->children; list; list = list->next) {
+			ETableGroupContainerChildNode *child_node = (ETableGroupContainerChildNode *)list->data;
+			ETableGroup *child = child_node->child;
+			int thisy;
+
+			e_table_group_get_cell_geometry (child, row, col, x, &thisy, width, height);
+			ypos += thisy;
+			if ((*row == -1) || (*col == -1)) {
+				ypos += TITLE_HEIGHT;
+				*x += GROUP_INDENT;
+				*y = ypos;
+				return;
+			}
+		}
+	}
+}
+
 static void etgc_thaw (ETableGroup *etg)
 {
 	e_canvas_item_request_reflow (GNOME_CANVAS_ITEM(etg));
@@ -721,6 +751,16 @@ etgc_set_arg (GtkObject *object, GtkArg *arg, guint arg_id)
 		}
 		break;
 
+	case ARG_TABLE_ALTERNATING_ROW_COLORS:
+		etgc->alternating_row_colors = GTK_VALUE_BOOL (*arg);
+		for (list = etgc->children; list; list = g_list_next (list)) {
+			ETableGroupContainerChildNode *child_node = (ETableGroupContainerChildNode *)list->data;
+			gtk_object_set (GTK_OBJECT(child_node->child),
+					"alternating_row_colors", GTK_VALUE_BOOL (*arg),
+					NULL);
+		}
+		break;
+
 	case ARG_TABLE_HORIZONTAL_DRAW_GRID:
 		etgc->horizontal_draw_grid = GTK_VALUE_BOOL (*arg);
 		for (list = etgc->children; list; list = g_list_next (list)) {
@@ -817,7 +857,10 @@ etgc_class_init (GtkObjectClass *object_class)
 	e_group_class->get_focus_column = etgc_get_focus_column;
 	e_group_class->get_printable = etgc_get_printable;
 	e_group_class->compute_location = etgc_compute_location;
+	e_group_class->get_cell_geometry = etgc_get_cell_geometry;
 
+	gtk_object_add_arg_type ("ETableGroupContainer::alternating_row_colors", GTK_TYPE_BOOL,
+				 GTK_ARG_WRITABLE, ARG_TABLE_ALTERNATING_ROW_COLORS);
 	gtk_object_add_arg_type ("ETableGroupContainer::horizontal_draw_grid", GTK_TYPE_BOOL,
 				 GTK_ARG_WRITABLE, ARG_TABLE_HORIZONTAL_DRAW_GRID);
 	gtk_object_add_arg_type ("ETableGroupContainer::vertical_draw_grid", GTK_TYPE_BOOL,
@@ -930,6 +973,7 @@ etgc_init (GtkObject *object)
 	
 	e_canvas_item_set_reflow_callback (GNOME_CANVAS_ITEM(object), etgc_reflow);
 
+	container->alternating_row_colors = 1;
 	container->horizontal_draw_grid = 1;
 	container->vertical_draw_grid = 1;
 	container->draw_focus = 1;
