@@ -67,7 +67,7 @@ typedef struct {
 	gint        (*get_focus_column)      (ETableGroup *etg);
 	EPrintable *(*get_printable)         (ETableGroup *etg);
 	void        (*compute_location)      (ETableGroup *etg, int *x, int *y, int *row, int *col);
-	void        (*get_position)          (ETableGroup *etg, int *x, int *y, int *row, int *col);
+	void        (*get_cell_geometry)     (ETableGroup *etg, int *row, int *col, int *x, int *y, int *width, int *height);
 
 } ETableGroupClass;
 
@@ -99,11 +99,13 @@ void          e_table_group_compute_location  (ETableGroup       *etg,
 					       int               *y,
 					       int               *row,
 					       int               *col);
-void          e_table_group_get_position      (ETableGroup       *etg,
+void          e_table_group_get_cell_geometry (ETableGroup       *etg,
+					       int               *row,
+					       int               *col,
 					       int               *x,
 					       int               *y,
-					       int               *row,
-					       int               *col);
+					       int               *width,
+					       int               *height);
 ETableGroup  *e_table_group_new               (GnomeCanvasGroup  *parent,
 					       ETableHeader      *full_header,
 					       ETableHeader      *header,
