@@ -8,12 +8,18 @@
  * (C) 1999, 2000 Helix Code, Inc.
  */
 #include <config.h>
+
+#include <util/e-i18n.h>
+#include <ctype.h>
+#include <string.h>
 #include <gtk/gtksignal.h>
+#include <gnome-xml/parser.h>
+#include <libgnome/gnome-defs.h>
+#include <libgnome/gnome-util.h>
 #include <gal/util/e-util.h>
 #include <gal/util/e-xml-utils.h>
-#include <gnome-xml/parser.h>
+#include <gal/widgets/e-unicode.h>
 #include "gal-view-collection.h"
-#include <ctype.h>
 
 #define GVC_CLASS(e) ((GalViewCollectionClass *)((GtkObject *)e)->klass)
 
@@ -23,6 +29,7 @@ static GtkObjectClass *gal_view_collection_parent_class;
 
 enum {
 	DISPLAY_VIEW,
+	CHANGED,
 	LAST_SIGNAL
 };
 
@@ -46,6 +53,16 @@ gal_view_collection_display_view (GalViewCollection *collection,
 			 view);
 }
 
+static void
+gal_view_collection_changed (GalViewCollection *collection)
+{
+	g_return_if_fail (collection != NULL);
+	g_return_if_fail (GAL_IS_VIEW_COLLECTION (collection));
+
+	gtk_signal_emit (GTK_OBJECT (collection),
+			 gal_view_collection_signals [CHANGED]);
+}
+
 static void
 gal_view_collection_item_free (GalViewCollectionItem *item)
 {
@@ -93,11 +110,20 @@ gal_view_collection_class_init (GtkObjectClass *object_class)
 				object_class->type,
 				GTK_SIGNAL_OFFSET (GalViewCollectionClass, display_view),
 				gtk_marshal_NONE__OBJECT,
-				GTK_TYPE_NONE, 1, GTK_TYPE_OBJECT);
+				GTK_TYPE_NONE, 1, GAL_VIEW_TYPE);
+
+	gal_view_collection_signals [CHANGED] =
+		gtk_signal_new ("changed",
+				GTK_RUN_LAST,
+				object_class->type,
+				GTK_SIGNAL_OFFSET (GalViewCollectionClass, changed),
+				gtk_marshal_NONE__NONE,
+				GTK_TYPE_NONE, 0);
 
 	gtk_object_class_add_signals (object_class, gal_view_collection_signals, LAST_SIGNAL);
 
-	klass->display_view = NULL;     
+	klass->display_view = NULL;
+	klass->changed      = NULL;
 }
 
 static void
@@ -197,6 +223,8 @@ view_changed (GalView *view,
 {
 	item->changed = TRUE;
 	item->ever_changed = TRUE;
+
+	gal_view_collection_changed(item->collection);
 }
 
 static GalViewCollectionItem *
@@ -211,9 +239,11 @@ load_single_file (GalViewCollection *collection,
 	item->changed = FALSE;
 	item->built_in = !local;
 	item->id = e_xml_get_string_prop_by_name(node, "id");
-	item->title = e_xml_get_string_prop_by_name(node, "title");
 	item->filename = e_xml_get_string_prop_by_name(node, "filename");
+	item->title = e_xml_get_translated_utf8_string_prop_by_name(node, "title");
 	item->type = e_xml_get_string_prop_by_name(node, "type");
+	item->collection = collection;
+
 	if (item->filename) {
 		GalViewFactory *factory;
 		GList *factories;
@@ -252,8 +282,10 @@ load_single_dir (GalViewCollection *collection,
 	char *filename = g_concat_dir_and_file(dir, "galview.xml");
 
 	doc = xmlParseFile(filename);
-	if (!doc)
+	if (!doc) {
+		g_free (filename);
 		return;
+	}
 	root = xmlDocGetRootElement(doc);
 	for (child = root->xmlChildrenNode; child; child = child->next) {
 		gchar *id = e_xml_get_string_prop_by_name(child, "id");
@@ -295,6 +327,7 @@ load_single_dir (GalViewCollection *collection,
 	}
 
 	g_free(filename);
+	xmlFreeDoc(doc);
 }
 
 /**
@@ -483,6 +516,7 @@ gal_view_collection_append                   (GalViewCollection *collection,
 	item->id = gal_view_generate_id(collection, view);
 	item->filename = g_strdup_printf("%s.galview", item->id);
 	item->view = view;
+	item->collection = collection;
 	gtk_object_ref(GTK_OBJECT(view));
 
 	gtk_signal_connect(GTK_OBJECT(item->view), "changed",
@@ -491,6 +525,8 @@ gal_view_collection_append                   (GalViewCollection *collection,
 	collection->view_data = g_renew(GalViewCollectionItem *, collection->view_data, collection->view_count + 1);
 	collection->view_data[collection->view_count] = item;
 	collection->view_count ++;
+
+	gal_view_collection_changed(collection);
 }
 
 void
@@ -509,6 +545,8 @@ gal_view_collection_delete_view              (GalViewCollection *collection,
 	} else {
 		gal_view_collection_item_free (item);
 	}
+
+	gal_view_collection_changed(collection);
 }
 
 void
@@ -527,6 +565,7 @@ gal_view_collection_copy_view                (GalViewCollection *collection,
 	item->id = gal_view_generate_id(collection, view);
 	item->filename = g_strdup_printf("%s.galview", item->id);
 	item->view = gal_view_clone(view);
+	item->collection = collection;
 
 	gtk_signal_connect(GTK_OBJECT(item->view), "changed",
 			   GTK_SIGNAL_FUNC(view_changed), item);
@@ -534,4 +573,6 @@ gal_view_collection_copy_view                (GalViewCollection *collection,
 	collection->view_data = g_renew(GalViewCollectionItem *, collection->view_data, collection->view_count + 1);
 	collection->view_data[collection->view_count] = item;
 	collection->view_count ++;
+
+	gal_view_collection_changed(collection);
 }
