@@ -35,6 +35,13 @@
 
 #include <config.h>
 #include <string.h>
+#include <gtk/gtkbutton.h>
+#include <gtk/gtkdnd.h>
+#include <gtk/gtkrc.h>
+#include <gtk/gtkselection.h>
+#include <gtk/gtksignal.h>
+#include <libgnome/gnome-defs.h>
+#include <libgnome/gnome-util.h>
 #include <gal/util/e-util.h>
 #include <gal/e-text/e-entry.h>
 #include "e-shortcut-bar.h"
@@ -223,6 +230,8 @@ e_shortcut_bar_init (EShortcutBar *shortcut_bar)
 
 	shortcut_bar->dragged_url = NULL;
 	shortcut_bar->dragged_name = NULL;
+
+	shortcut_bar->enable_drags = TRUE;
 }
 
 
@@ -412,6 +421,8 @@ e_shortcut_bar_add_group	(EShortcutBar	*shortcut_bar,
 		"pressed", GTK_SIGNAL_FUNC (e_shortcut_bar_stop_editing), shortcut_bar);
 
 	group->icon_bar = e_icon_bar_new ();
+	e_icon_bar_set_enable_drags (E_ICON_BAR (group->icon_bar),
+				     shortcut_bar->enable_drags);
 	gtk_widget_show (group->icon_bar);
 	gtk_container_add (GTK_CONTAINER (group->vscrolled_bar),
 			   group->icon_bar);
@@ -810,3 +821,27 @@ e_shortcut_bar_load_image (const gchar *filename)
 
 	return image;
 }
+
+
+/* Set whether items can be dragged, for drag-and-drop. */
+void
+e_shortcut_bar_set_enable_drags    (EShortcutBar	 *shortcut_bar,
+				    gboolean	          enable_drags)
+{
+	EShortcutBarGroup *group;
+	gint group_num;
+
+	g_return_if_fail (E_IS_SHORTCUT_BAR (shortcut_bar));
+
+	shortcut_bar->enable_drags = enable_drags;
+
+	for (group_num = 0;
+	     group_num < shortcut_bar->groups->len;
+	     group_num++) {
+		group = &g_array_index (shortcut_bar->groups,
+					EShortcutBarGroup, group_num);
+		e_icon_bar_set_enable_drags (E_ICON_BAR (group->icon_bar),
+					     enable_drags);
+	}
+}
+
